//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU Library General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

#include <stdio.h>
#include "ArmyDialog.h"
#include "defs.h"

ArmyDialog::ArmyDialog(Army* army, PG_Widget* parent, PG_Rect rect)
    :PG_Window(parent, rect, _("Army info"), WF_MODAL), d_army(army)
{
    char buffer[61];
    buffer[60] = '\0';
    unsigned int bonus;

    //I assume a size of 500*400 pixels here
    
    d_b_ok = new PG_Button(this, 1, PG_Rect(350, 360, 130, 30),
                            _("OK"));
    d_b_ok->SetEventObject(MSG_BUTTONCLICK, this,
                        (MSG_CALLBACK_OBJ)&ArmyDialog::b_ok_clicked);

    //the army pic
    d_b_pic = new PG_Button(this, 2, PG_Rect(100, 100, 50, 50), "");
    d_b_pic->EnableReceiver(false);
    d_b_pic->SetIcon(d_army->getPixmap(), 0, 0);

    //the name of the army
    d_l_name = new PG_Label(this, PG_Rect(250, 50, 200, 20), 
                            d_army->getName().c_str());
                            
    //the head of the table for the single values
    d_l_basic = new PG_Label(this, PG_Rect(400, 70, 45, 20), _("basic"));
    d_l_real = new PG_Label(this, PG_Rect(450, 70, 45, 20), _("real"));

    //and the values themselves
    d_l_strengthn = new PG_Label(this, PG_Rect(250, 90, 95, 20), _("strength"));
    snprintf(buffer, 60, "%i", d_army->getMaxStrength());
    d_l_strengthb = new PG_Label(this, PG_Rect(400, 90, 45, 20), buffer);
    snprintf(buffer, 60, "%i", d_army->getStrength());
    d_l_strengthr = new PG_Label(this, PG_Rect(450, 90, 45, 20), buffer);
    if (d_army->getMaxStrength() < d_army->getStrength())
        d_l_strengthr->SetFontColor(50, 255, 50);   //green highlight
    if (d_army->getMaxStrength() > d_army->getStrength())
        d_l_strengthr->SetFontColor(200, 30, 30);   //red highlight

    d_l_defensen = new PG_Label(this, PG_Rect(250, 110, 95, 20), _("defense"));
    snprintf(buffer, 60, "%i", d_army->getDefense());
    d_l_defenseb = new PG_Label(this, PG_Rect(400, 110, 45, 20), buffer);
    d_l_defenser = new PG_Label(this, PG_Rect(450, 110, 45, 20), buffer);

    d_l_vitalityn = new PG_Label(this, PG_Rect(250, 130, 96, 20), _("vitality"));
    snprintf(buffer, 60, "%i", d_army->getVitality());
    d_l_vitalityb = new PG_Label(this, PG_Rect(400, 130, 45, 20), buffer);
    d_l_vitalityr = new PG_Label(this, PG_Rect(450, 130, 45, 20), buffer);

    d_l_hpn = new PG_Label(this, PG_Rect(250, 150, 95, 20), _("hp"));
    snprintf(buffer, 60, "%i", d_army->getMaxHp());
    d_l_hpb = new PG_Label(this, PG_Rect(400, 150, 45, 20), buffer);
    snprintf(buffer, 60, "%i", d_army->getHP());
    d_l_hpr = new PG_Label(this, PG_Rect(450, 150, 45, 20), buffer);
    if (d_army->getHP() < d_army->getMaxHp())
        d_l_hpr->SetFontColor(200, 30, 30);

    d_l_movesn = new PG_Label(this, PG_Rect(250, 170, 95, 20), _("moves"));
    snprintf(buffer, 60, "%i", d_army->getMaxMoves());
    d_l_movesb = new PG_Label(this, PG_Rect(400, 170, 45, 20), buffer);
    snprintf(buffer, 60, "%i", d_army->getMoves());
    d_l_movesr = new PG_Label(this, PG_Rect(450, 170, 45, 20), buffer);
    if (d_army->getMoves() < d_army->getMaxMoves())
        d_l_movesr->SetFontColor(200, 30, 20);

    snprintf(buffer, 60, _("xp: %.2f"), d_army->getXP());
    d_l_xp = new PG_Label(this, PG_Rect(250, 200, 95, 20), buffer);
    snprintf(buffer, 60, _("level: %i"), d_army->getLevel());
    d_l_level = new PG_Label(this, PG_Rect(400, 200, 95, 20), buffer);

    if (d_army->getProduction()==-1) 
         snprintf(buffer, 60, _("prod. time: None"));
    else 
         snprintf(buffer, 60,
                 ngettext("prod. time: %i turn","prod. time: %i turns",d_army->getProduction()),
                 d_army->getProduction());
    d_l_prod = new PG_Label(this, PG_Rect(350, 270, 145, 20), buffer);

    if (d_army->getProductionCost()==-1) 
         snprintf(buffer, 60, _("prod. cost: None"));
    else 
         snprintf(buffer, 60, _("prod. cost: %i gold"), d_army->getProductionCost());
    d_l_prodcost = new PG_Label(this, PG_Rect(350, 290, 165, 20), buffer);

    snprintf(buffer, 60, _("Upkeep: %i gold"), d_army->getUpkeep());
    d_l_upkeep = new PG_Label(this, PG_Rect(350, 310, 145, 20), buffer);

    d_l_movebonusv = 0;       
    d_l_movebonusn = new PG_Label(this, PG_Rect(200, 230, 160, 20), _("move bonus"));
    bonus = d_army->getMoveBonus();

    if (bonus & MAPTILE_WATER)
        d_l_movebonusv = new PG_Label(this, PG_Rect(200, 260, 100, 20),_("Water"));

    if (bonus & MAPTILE_FOREST)
        d_l_movebonusv = new PG_Label(this, PG_Rect(200, 290, 100, 20),_("Forest"));

    if (bonus & MAPTILE_HILL)
        d_l_movebonusv = new PG_Label(this, PG_Rect(200, 320, 100, 20),_("Hill"));

    if (bonus & MAPTILE_SWAMP)
        d_l_movebonusv = new PG_Label(this, PG_Rect(200, 350, 100, 20),_("Swamp"));

    if (d_l_movebonusv) d_l_movebonusv->SetFontColor(200, 30, 30);

    d_l_armybonusv = 0;

    d_l_armybonusn = new PG_Label(this, PG_Rect(30, 230, 100, 20), _("bonus"));
    bonus = d_army->getArmyBonus();
    if (bonus & ARMY_SHIP)
        d_l_armybonusv = new PG_Label(this,PG_Rect(30,260, 150, 20), _("Move on water"));
    if (bonus & ARMY_HERO)
        d_l_armybonusv = new PG_Label(this,PG_Rect(30,280, 150, 20), _("Is a Hero"));
    if (bonus & ARMY_CAVALRY)
        d_l_armybonusv = new PG_Label(this, PG_Rect(30, 300, 150, 20), _("Stronger on grass"));
    if (bonus & ARMY_ANTICAVALRY)
        d_l_armybonusv = new PG_Label(this, PG_Rect(30, 320, 150, 20), _("Stronger vs cavalry"));
    if (bonus & ARMY_HEALFAST)
        d_l_armybonusv = new PG_Label(this, PG_Rect(30, 340, 150, 20), _("Healfast"));
    if (bonus & ARMY_EVADE)
        d_l_armybonusv = new PG_Label(this, PG_Rect(30, 360, 150, 20), _("Evade"));
    if (bonus & ARMY_CRITICAL)
        d_l_armybonusv = new PG_Label(this, PG_Rect(30, 380, 150, 20), _("Assassin"));

    if (d_l_armybonusv) d_l_armybonusv->SetFontColor(200, 30, 30);
}

ArmyDialog::~ArmyDialog()
{
    delete d_b_ok;
    delete d_b_pic;
    delete d_l_name;
    delete d_l_basic;
    delete d_l_real;
    delete d_l_strengthn;
    delete d_l_strengthb;
    delete d_l_strengthr;
    delete d_l_defensen;
    delete d_l_defenseb;
    delete d_l_defenser;
    delete d_l_vitalityn;
    delete d_l_vitalityb;
    delete d_l_vitalityr;
    delete d_l_hpn;
    delete d_l_hpb;
    delete d_l_hpr;
    delete d_l_movesn;
    delete d_l_movesb;
    delete d_l_movesr;
    delete d_l_prod;
    delete d_l_prodcost;
    delete d_l_upkeep;
    delete d_l_xp;
    delete d_l_level;
    delete d_l_movebonusn;
    delete d_l_armybonusn;

   if (d_l_movebonusv)
        delete d_l_movebonusv;

   if (d_l_armybonusv)
	delete d_l_armybonusv;
}

PARAGUI_CALLBACK(ArmyDialog::b_ok_clicked)
{
    SendMessage(this, MSG_MODALQUIT, 0, 0);
    return true;
}
