//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU Library General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

#ifndef FIGHTDIALOG_H
#define FIGHTDIALOG_H

#include <vector>
#include <pgeventobject.h>
#include <pgthemewidget.h>
#include <pglabel.h>
#include "fight.h"

class Stack;

/** \brief FightDialog implements the graphical part of a fight
  * 
  * The code for a fight is splitted over two classes: FightDialog and fight.
  * This class only contains the graphical portion of the code (drawing armies
  * and such), the fight class implements the "logic". The FightDialog class
  * uses the fight class for the actual calculations.
  */

class FightDialog : public PG_EventObject, public PG_ThemeWidget
{ 
        public:
        /** The constructor
          * 
          * @param attacker     a vector of stacks containing the attacking stacks
          * @param defender     a vector of stacks containing the defending stacks
          * @param parent       the parent widget
          * @param def_bonus    if set to true, the defender will gain a defense
          *                     bonus from the terrain (set to false e.g. when
          *                     searching a ruin)
          */
        FightDialog(std::vector<Stack*>& attacker,
                    std::vector<Stack*>& defender,
                    PG_Widget* parent,
                    bool def_bonus = true);

        /** An alternate constructor if there are only one attacking and
          * defending stack
          */
        FightDialog(Stack* attacker, Stack* defender, PG_Widget* parent,
                    bool def_bonus = true);
        
        ~FightDialog();

        //! Start the battle
        void battle();

        //! Return the result of the fight (attacker/defender/none won)
        Fight::RESULT getResult() const {return d_result;}

        private:

        //! Initiate the dialog
        void initScreen();
       
        //! Inherited from PG_Widget
        void eventDraw(SDL_Surface* surface, const PG_Rect& rect);

        /** Draw an army at a given pixel position with a hitpoints bar
          * 
          * @param surface  the surface to draw to
          * @param x        the x-coordinate where the army should be drawn
          * @param y        the y-coordinate where the army should be drawn
          * @param unit     the army to draw
          */
        void drawArmy (SDL_Surface* surface, int x, int y, Army* unit);

        
        // DATA
        std::vector<Stack*> d_attacker;
        std::vector<Stack*> d_defender;
        bool d_def_bonus;
        int d_turn;
        PG_Label* d_l_turn;
        Fight::RESULT d_result;
        static const int ROUND_DELAY = 300;
};

#endif // FIGHTDIALOG_H
