//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU Library General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

#ifndef RENDGAME_H
#define RENDGAME_H

#include <sigc++/sigc++.h>
#include "Reaction.h"

/** This reaction ends the game. It doesn't determine a winning or loosing side
  * but just signals that the game should be finished. Since such a small
  * class cannot know what has to happen if a game is signalled to end, it just
  * emits a signal which has to be connected properly by some administrative
  * class.
  */

class REndGame : public Reaction
{
    public:
        REndGame();
        REndGame(XML_Helper* helper);
        virtual ~REndGame();

        //! Saves the reaction data
        bool save(XML_Helper* helper);

        //! Triggers the reaction
        bool trigger();

        //! Connects the internal signal to a slot.
        static void connect(SigC::Slot0<void> slot);

    protected:
        static SigC::Signal0<void> d_signal;
};

#endif //RENDGAME_H
