//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU Library General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

#ifndef REACTION_H
#define REACTION_H

#include "xmlhelper.h"

/** Defines an action if a certain event occurs
  * 
  * When an event is triggered, something happens. We implement this by
  * defining an event class and a reaction class. While the event class
  * just hooks up to a signal, the real action is done by a reaction class
  * (such as winning/losing a game, getting reinforcements etc.). All
  * reaction classes have the function trigger which, well, triggers the
  * action.
  *
  * Reactions implemented so far:
  * REndGame:       ends the current game (doesn't care about wins or losses)
  * RMessage:       display a message box with some text
  * RAddGold:       adds some gold to a specific player
  * RAddUnit:       adds an army to a player
  */

class Reaction
{
    public:
        enum TYPE {ENDGAME, MESSAGE, ADDGOLD, ADDUNIT};
        
        Reaction(TYPE type);
        virtual ~Reaction();

        /** Load a reaction
          * 
          * @param helper   an XML_Helper instance of a savegame
          *
          * This function determines the reaction type and loads the appropriate
          * class.
          */
        static Reaction* loadReaction(XML_Helper* helper);

        //! Saves the reaction data
        virtual bool save(XML_Helper* helper) = 0;

        //! Triggers the action
        virtual bool trigger() = 0;

    protected:
        TYPE d_type;
};


#endif //REACTION_H
