//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU Library General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

#include "TileSet.h"
#include <SDL_image.h>
#include <iostream>
#include "File.h"

using namespace std;

//#define debug(x) {cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<endl;}
#define debug(x)

TileSet::TileSet(string fileName)
{
    debug("TileSet(): " << fileName)

    // used to load the tiles at the correct type position in loadTile()
    tiles.resize(6);

    //Get mapset picture
    d_surface = File::getMapsetPicture(fileName, fileName + ".png");
    XML_Helper helper(File::getMapset(fileName), ios::in, false);
    helper.registerTag("tileset", SigC::slot((*this), &TileSet::loadTileSet));
    helper.registerTag("tile", SigC::slot((*this), &TileSet::loadTile));
    helper.parse();
}

TileSet::~TileSet()
{
    SDL_FreeSurface(d_surface);
    for (unsigned int i=0; i<tiles.size(); i++)
    {
        delete tiles[i];
    }
}

bool TileSet::loadTile(string, XML_Helper* helper)
{
    debug("loadTile()")
    int r, g, b, moves, defense;
    unsigned int type;
    string name;
    static int counter = 0;

    helper->getData(name, "name");
    helper->getData(moves, "moves");
    helper->getData(defense, "defense");
    helper->getData(defense, "defense");
    helper->getData(r, "red");
    helper->getData(g, "green");
    helper->getData(b, "blue");
    helper->getData(type, "type");
    SDL_Color color;
    color.r = r;
    color.g = g;
    color.b = b;

    // create a new tile with the information we got
    Tile* tile = new Tile();
    // add to tileset
    tile->setName(name);
    tile->setMoves(moves);
    tile->setDefense(defense);
    tile->setColor(color);
    tile->setType(type);
    
    createTiles(tile, counter);
    tile->printDebugInfo();

    tiles[type] = tile;

    counter++;
    return true;
}

bool TileSet::loadTileSet(string, XML_Helper* helper)
{
    helper->getData(d_name, "name"); 
    helper->getData(d_info, "info");
    helper->getData(d_tileSize, "tilesize");
    return true;
}

// creatTiles creates all corners out of the 8 given tiles

void TileSet::createTiles(Tile* tile, int row)
{
    SDL_Rect src;
    src.w = d_tileSize/2;
    src.h = d_tileSize/2;

    for (int i=0; i < 8; i++)
    {
        // corner 1
        src.x = i*d_tileSize;
        src.y = row*d_tileSize;
        SDL_BlitSurface(d_surface, &src, tile->getSurface(i*4), 0);

        // corner 2
        src.x = i*d_tileSize + d_tileSize/2;
        src.y = row*d_tileSize;
        SDL_BlitSurface(d_surface, &src, tile->getSurface(i*4+1), 0);

        // corner 3
        src.x = i*d_tileSize;
        src.y = row*d_tileSize + d_tileSize/2;
        SDL_BlitSurface(d_surface, &src, tile->getSurface(i*4+2), 0);

        // corner 4
        src.x = i*d_tileSize + d_tileSize/2;
        src.y = row*d_tileSize + d_tileSize/2;
        SDL_BlitSurface(d_surface, &src, tile->getSurface(i*4+3), 0);
    }
}

// End of file
