//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU Library General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

#include "d_buy_production.h"
#include "army.h"
#include "armyset.h"
#include "city.h"
#include "player.h"
#include "GraphicsCache.h"

using namespace std;

D_Buy_Production::D_Buy_Production(City* city, PG_Widget* parent, PG_Rect rect)
    :PG_Window(parent, rect, _("Buy Production"), WF_MODAL)
{
    d_city = city;
    d_armyset = city->getPlayer()->getArmyset();
    d_gold = city->getPlayer()->getGold();
    d_chosenArmy = -1;

    int ca;        // current army
    int ci;        // current index

    //for all armies except the heroes
    for (int i = 0; i <= ((d_armyset->getSize()-2)/5) ; i++)
    {
        for (int j = 0; j < 5; j++)
        {
            ci = i*5 + j;
            ca = ci + 2;

            if (ca >= d_armyset->getSize())
                continue;
            
            SDL_Surface* armyPic = GraphicsCache::getInstance()->getArmyPic(
                                    d_armyset->getName(), ca,
                                    d_city->getPlayer(),1);
            d_b_production[ci] = new PG_Button(this, ci, PG_Rect(20 + j*44, i*44 + 30, 44, 44));
            d_b_production[ci]->SetToggle(true);
            d_b_production[ci]->SetIcon(armyPic, 0, 0);
            d_b_production[ci]->SetEventObject(MSG_BUTTONCLICK, this,
                    (MSG_CALLBACK_OBJ)&D_Buy_Production::b_productionClicked);

        }
    }

    d_l_production = new PG_Label(this, PG_Rect(20, 180, 140, 20), _("Name:"));
    d_l_duration = new PG_Label(this, PG_Rect(20, 200, 140, 20), _("Duration:"));
    d_l_upkeep = new PG_Label(this, PG_Rect(20, 220, 140, 20), _("Upkeep:"));
    d_l_moves = new PG_Label(this, PG_Rect(20, 240, 140, 20), _("Moves:"));
    d_l_productionCost = new PG_Label(this, PG_Rect(20, 260, 180, 20), _("Production cost:"));
    
    d_l_strength = new PG_Label(this, PG_Rect(170, 180, 140, 20), _("Strength:"));
    d_l_defense = new PG_Label(this, PG_Rect(170, 200, 140, 20), _("Defense:"));
    d_l_hp = new PG_Label(this, PG_Rect(170, 220, 140, 20), _("Hitpoints:"));
    
    d_b_buy = new PG_Button(this, 11, PG_Rect(260, 30, 60, 30), _("Buy"));
    d_b_cancel = new PG_Button(this, 11, PG_Rect(260, 70, 60, 30), _("Cancel"));

    d_b_buy->EnableReceiver(false);
    d_b_buy->SetEventObject(MSG_BUTTONCLICK, this,
            (MSG_CALLBACK_OBJ)&D_Buy_Production::b_buyClicked);
    d_b_cancel->SetEventObject(MSG_BUTTONCLICK, this,
            (MSG_CALLBACK_OBJ)&D_Buy_Production::b_cancelClicked);
}

D_Buy_Production::~D_Buy_Production()
{
    for (int i = 0; i < 10; i++)
    {
        delete d_b_production[i];
    }
    delete d_l_production;
    delete d_l_duration;
    delete d_l_strength;
    delete d_l_defense;
    delete d_l_hp;
    delete d_l_moves;
    delete d_l_upkeep;
    delete d_b_buy;
    delete d_b_cancel;
}

PARAGUI_CALLBACK(D_Buy_Production::b_buyClicked)
{
    QuitModal();
    return true;
}

PARAGUI_CALLBACK(D_Buy_Production::b_cancelClicked)
{
    d_chosenArmy = -1;
    SendMessage(this, MSG_MODALQUIT, 0, 0);
    return true;
}

PARAGUI_CALLBACK(D_Buy_Production::b_productionClicked)
{
    d_chosenArmy = id + 2;

    // deselect all other buttons
    for (int i = 0; i < d_armyset->getSize() - 2; i++)
    {
        if (i != id) d_b_production[i]->SetPressed(false);
    }

    // selected armytype
    Armyset_army* a = &d_armyset->army[d_chosenArmy];
    string name = "Name: " + a->getName();

    d_l_production->SetText(name.c_str());
    char buffer[40];
    sprintf(buffer, _("Duration: %i"), a->getProduction());
    d_l_duration->SetText(buffer);
    sprintf(buffer, _("Strength: %i"), a->getMaxStrength());
    d_l_strength->SetText(buffer);
    sprintf(buffer, _("Defense: %i"), a->getDefense());
    d_l_defense->SetText(buffer);
    sprintf(buffer, _("Hitpoints: %i"), a->getMaxHp());
    d_l_hp->SetText(buffer);
    sprintf(buffer, _("Moves: %i"), a->getMaxMoves());
    d_l_moves->SetText(buffer);
    sprintf(buffer, _("Upkeep: %i"), a->getUpkeep());
    d_l_upkeep->SetText(buffer);
    sprintf(buffer, _("Production cost: %i"), a->getProductionCost());
    d_l_productionCost->SetText(buffer);

    // enough money to buy this production-type or have it already?
    if (a->getProductionCost() > d_gold || d_city->hasProduction(d_chosenArmy))
    {
        d_b_buy->EnableReceiver(false);
    } else {
        // allow to press buy button
        d_b_buy->EnableReceiver(true);
    }
    return true;
}
